% Basic descriptive statistice with MATLAB

% Data example, daily temperature in Innsbruck August 2002 at 7 a.m.
T = [16.9 15.1 15.7	16.6 16.2 14.8 13.6	13.3 14.8 15.6 13.5	14.6 13.3 12.3 12 14.6 15.2	15.5 15.2 16.2	15.5 13	12.9 14.6 15.8 15.7	16.4 16	16.4 14.7 14.2];

hist(T); % bar charts of absolute frequencies
hist(T,5);

minT = min(T);
maxT = max(T);

centers = minT-0.5:0.5:maxT+0.5;
hist(T,centers); % bar charts of absolute frequencies with bins centered at "centers"

h = findobj(gca,'Type','patch');
set(h,'FaceColor','y','Edgecolor','k'); % changing colos in the bar chart

% Producing the same picture with more control variables

edges = centers(1)-0.25:0.5:centers(end)+0.25;
count = histc(T,edges);
count = count(1:end-1); % delete last entry, because it is the number of values hitting exactly the right boundary
bar(centers,count)
bar(centers,count,1)
bar(centers,count,1,'facecolor','y', 'edgecolor','k')

% Normalizing to area 1 to produce a true histogram

prop = count/31;
bar(centers,prop,1,'facecolor','y', 'edgecolor','k')

% Plotting the cumulative distribution function

cdfplot(T)
axis([minT-1 maxT+1 0 1])

% Producing the same picture with more control variables

cum = cumsum(prop);
bar(centers,cum,1,'facecolor','b', 'edgecolor','w') % shortcut with the "bar"-function

% Mathematically correct plot of the cumulative distriubution function

figure
hold on
for i = 1:length(centers)
    plot([centers(i)-0.25, centers(i)+0.25], [cum(i) cum(i)],'k','linewidth',2)
end
plot([centers(1)-1, centers(1)-0.25], [0 0],'k','linewidth',2)
plot([centers(end)+0.25, centers(end)+1], [1 1],'k','linewidth',2)
hold off
axis([centers(1)-1, centers(end)+1, 0, 1])

%$ Producing a boxplot

boxplot(T)

% Various statistical sample parameters

mean(T)
std(T)
var(T)
mode(T)
median(T)
quantile(T,[0.25 0.50 0.75])

% Plotting given types of distributions

x = -3:0.1:3;
plot(x,normpdf(x,0,1))
plot(x,normcdf(x,0,1))

